YulSwitch

Struct YulSwitch 

pub struct YulSwitch {
    pub loc: Loc,
    pub condition: YulExpression,
    pub cases: Vec<YulSwitchOptions>,
    pub default: Option<YulSwitchOptions>,
}
A Yul switch statement.

switch <condition> <cases>* [default <default>]

Enforced by the parser:

  • cases is guaranteed to be a Vec of YulSwitchOptions::Case.
  • default is guaranteed to be YulSwitchOptions::Default.
  • At least one of cases or default must be non-empty/Some respectively.

Fields

loc: Loc

The code location.

condition: YulExpression

The switch condition.

cases: Vec<YulSwitchOptions>

The switch cases.

default: Option<YulSwitchOptions>

The optional default case.